# Building _Commit_

---

## Prerequisites (all platforms)

Install **Python 3.9** or **3.10** and the Python packages in requirements.txt. We are not yet supporting Python 3.11
or later due to incompatibility with dependencies, so don't even try unless you're willing to waste a lot of time :-)

---

## Windows:

Make sure you have `py2exe` set up.

Run the `build-windows.cmd` script to build (output will be in dist/).

Option Flags:

* /c = clean the build directory first
* /n = disable auto-update function (i.e., building for app stores)
* /s = build a source ZIP

Package Flags:

* /i = build a Nullsoft installer ([NSIS](https://nsis.sourceforge.io/Download) and [LockedList](https://nsis.sourceforge.io/LockedList_plug-in) required)
* /z = also make a ZIP

---

## MacOS:

Make sure you have `py2app` set up.

Run the `build-mac.sh` script to build (output will be in dist/).

By default, it'll build for the current architecture. Use the /u option to build an Apple Universal2
binary (x86_64+ARM64). This will only work if you run it in the Universal2 version of Python.

Option Flags:

* -c = clean the build directory first
* -n = disable auto-update function (i.e., building for app stores)
* -u = build universal binary (requires universal Python from [Python.org](https://www.python.org/downloads/macos/))
* -s = build a source tarball

Package Flags:

* -cs _CERT_ = sign the code for distribution (replace "CERT" with your cert ID)
* -d = build a DMG for distribution ([Node.js](https://nodejs.org/en/download/) and [appdmg](https://www.npmjs.com/package/appdmg) required)
* -z = build a ZIP for notarization or distribution

When code signing, replace _CERT_ with your certificate ID. You can find it using this command:

* `security find-identity -v -p codesigning`

### Mac App Notarization

The code signing script _should_ get everything ready, signed,  and good-to-go for Apple's app
notarization process...which is finicky and annoying. Here are the basic steps:

* Build a package ZIP using the -z flag; Apple requires the app submission as a ZIP file.
* **one time prep:** `xcrun notarytool store-credentials "AC_PASSWORD" --apple-id "your@email" --team-id "TEAMID" --password "your_one_use_password"`
* `xcrun notarytool submit ./dist/commit_macos_VER.zip --keychain-profile "AC_PASSWORD" --wait`

---

## Linux:

Note requirements for the different package formats under the package flags.

Run the `build-linux.sh` script to build various package types (output will be in dist/).

Option flags:

* -c = clean the build directory first
* -n = disable auto-update function (i.e., building for app stores)
* -s = build a source tarball

Package flags:

* -f = make a Flatpak (flatpak, flatpak-builder, and pypandoc required)
* -d = make a DEB (dpkg-deb and debhelper required)
* -r = make an RPM (rpmdevtools and rpmbuild required)
* -t = make a tarball for manual install

### Flatpak Python Requirements

Get the [flatpak-pip-generator script](https://github.com/flatpak/flatpak-builder-tools/tree/master/pip) and put it next
to your commit source root directory. Then you can run it from the same directory where you would run ./build-linux.sh
by doing something like this:

`cd ./commit/assets/installer/lin/flatpak && ../../../../../../flatpak-pip-generator --requirements-file python3-requirements.txt --output python3-requirements --yaml && cd ../../../../../`

Note that the Flatpak requirements.txt does not include *lxml*, *markdown*, or *pygobject* because these are included
in the Flatpak Gnome runtime and do not need to be packaged manually. Also note that we are using wxPython 4.1.1 because
4.2.0 won't build. This is a known issue (see [bug #2296](https://github.com/wxWidgets/Phoenix/issues/2296)). We should
be able to update to use 4.2.1 whenever it is released with the fix for the linked issue.

---

## Haiku:

You might not have ever heard of [Haiku](https://www.haiku-os.org/), but I have!

Commit can run on Haiku, but it still needs some work. Theming isn't great, Pandoc is missing, and there are other bugs.
We do not yet support building HPKG packages for easy, user-friendly installation either. Commit is not a native Haiku
app, and there is no native Haiku version of wxPython, so we're using GTK as our interface.

The instructions below are for setting up a working environment that will run Commit, if you want to develop and refine
the app on that platform.

### Prerequisites

First, install the dependencies that are in the Haiku repos:

`pkgman install python3.9 pip_python39 beautifulsoup_python39 lxml_python39 markdown_python39 numpy_python39 pillow_python39 pyyaml_python39 wxgtk wxgtk_devel`

Next, install a few remaining requirements through Python's pip tool:

`pip3.9 install attrdict3 appdirs pygobject pypandoc`

Then download the [wxPython 4.2.0 source tarball](https://github.com/wxWidgets/Phoenix/releases/download/wxPython-4.2.0/wxPython-4.2.0.tar.gz) and untar it in a convenient place.

### Code Changes

There are a whopping two places in the wxPython source where it tries to use gdkx.h (GDK's X11 API), which won't work
because Haiku isn't using X11 (it's using Wayland) and the Haiku package for gtk3_devel (dependency of wxgtk_devel)
doesn't include the X11 libs anyway.

First, `/sip/cpp/sip_corewxWindow.cpp` - comment out the `__WXGTK__` section around lines 47-69 and change the
`wxPyGetWinHandle` function so it returns on GTK the same way it does on Windows and Mac (not using X11 functions)

Second, `/sip/cpp/sip_corewxPyApp.cpp` - comment out the import of `gdkx.h` and set the display check around lines
324-328 so they always just return `True`.

### Build wxPython!

Now run this:

`python3.9 ./build.py build_py --use_syswx`

If it works, run this next:

`python3.9 ./build.py install_py --use_syswx`

Now you should be able to run Commit by going to the root source dir and running:

`python3.9 ./commit.py`

Good luck!
