import locale               # Python Locale - https://docs.python.org/3/library/locale.html
import gettext              # Python Gettext - https://docs.python.org/3/library/gettext.html
import os                   # Python OS - https://docs.python.org/3/library/os.html
import pathlib              # Python Pathlib - https://docs.python.org/3/library/pathlib.html
import sys                  # Python Sys - https://docs.python.org/3/library/sys.html

import wx                   # wxPython - https://wxpython.org/


# force working directory to the right place (Windows py2exe only)
if wx.Platform == "__WXMSW__":
    app_path = pathlib.Path(sys.path[0])
    if app_path.is_dir():
        os.chdir(app_path)
    else:
        os.chdir(app_path.parent)

current_locale, encoding = locale.getdefaultlocale()
locale_path = "locale/"
translation = gettext.translation("commit", locale_path, [current_locale], fallback=True)
_ = translation.gettext

# Universal values for the app.
vendor_name = "intersanity"
vendor_display_name = "Intersanity Enterprises"
vendor_product_code = "IEOS-00039-A$01"
app_name = "commit"
app_display_name = "Commit"
app_tagline = _("the Advanced Modern Typewriter")
app_version = pathlib.Path("./version.txt").read_text()
app_credit = vendor_display_name + " " + _("and contributors")
app_website = "https://www.intersanity.com/software/commit/"
app_help_url = "https://www.intersanity.com/software/commit/manual/"
app_update_url = "https://update.intersanity.com/commit/stable.txt"
app_donate_url = "https://www.intersanity.com/software/commit/donate/"
debug = False

# Some additional constants have to be set at runtime (see commit.py)
icon = None

# other things
themes = [
    ["auto", _("System")],
    ["light", _("Light")],
    ["dark", _("Dark")]
]

fs_ratio_map = [
    [0.5625, "9:16"],
    [0.6667, "2:3"],
    [0.75, "3:4"],
    [1, "1:1"],
    [1.3333, "4:3 (" + _("default") + ")"],
    [1.5, "3:2"],
    [1.7778, "16:9"],
    [0, _("Full Screen")]
]

dark_flags = [
    "-dark",
    "-Dark",
    "-black",
    "-Black"
]

api_str = b'3c64697620616c69676e3d227269676874223e3c777870206d6f64756c653d22636f6d6d69742e696e636c756465732e6375' \
          b'73746f6d6f626a656374732220636c6173733d2248797065724c696e6b42746e223e3c706172616d206e616d653d226c6162' \
          b'656c222076616c75653d22cf80223e3c706172616d206e616d653d2275726c222076616c75653d2268747470733a2f2f7777' \
          b'772e796f75747562652e636f6d2f77617463683f763d705850584d787358543238223e3c706172616d206e616d653d226267' \
          b'5f636f6c6f72222076616c75653d227b307d223e3c706172616d206e616d653d2266675f636f6c6f72222076616c75653d22' \
          b'7b317d223e3c706172616d206e616d653d22756e646572222076616c75653d227b327d223e3c2f7778703e3c2f6469763e'

# date format mappings
#   our code string: [0 = wx.lib.masked format; 1 = strftime format]

date_formats = {
    "us/12": [
        "USDATETIMEMMDDYYYY/HHMMSS",
        "%m/%d/%Y %I:%M:%S %p"
    ],
    "us/24": [
        "USDATE24HRTIMEMMDDYYYY/HHMMSS",
        "%m/%d/%Y %H:%M:%S"
    ],
    "us-12": [
        "USDATETIMEMMDDYYYY-HHMMSS",
        "%m-%d-%Y %I:%M:%S %p"
    ],
    "us-24": [
        "USDATE24HRTIMEMMDDYYYY-HHMMSS",
        "%m-%d-%Y %H:%M:%S"
    ],
    "eu/12": [
        "EUDATETIMEYYYYMMDD/HHMMSS",
        "%Y/%m/%d %I:%M:%S %p"
    ],
    "eu/24": [
        "EUDATE24HRTIMEYYYYMMDD/HHMMSS",
        "%Y/%m/%d %H:%M:%S"
    ],
    "eu.12": [
        "EUDATETIMEYYYYMMDD.HHMMSS",
        "%Y.%m.%d %I:%M:%S %p"
    ],
    "eu.24": [
        "EUDATE24HRTIMEYYYYMMDD.HHMMSS",
        "%Y.%m.%d %H:%M:%S"
    ]
}

# these are the conversion formats (will be checked later against system support)

# HTML first (it's the default); the rest in alphabetical order by name
conversion_formats = {
    "html": {
        "name": _("HyperText Markup Language (HTML)"),
        "extension": ".html",
        "import": True,
        "export_file": True,
        "export_clip": True
    },
    "commonmark_x": {
        "name": _("CommonMark (Markdown)"),
        "extension": ".md",
        "import": True,
        "export_file": True,
        "export_clip": True
    },
    "docbook": {
        "name": _("DocBook"),
        "extension": ".dbk",
        "import": True,
        "export_file": True,
        "export_clip": False
    },
    "epub": {
        "name": _("EPUB eBook"),
        "extension": ".epub",
        "import": True,
        "export_file": True,
        "export_clip": False
    },
    "odt": {
        "name": _("LibreOffice Text (OpenDocument Text)"),
        "extension": ".odt",
        "import": True,
        "export_file": True,
        "export_clip": False
    },
    "docx": {
        "name": _("Microsoft Word (Office Open XML Document)"),
        "extension": ".docx",
        "import": True,
        "export_file": True,
        "export_clip": False
    },
    "txt": {
        "name": _("Plain Text"),
        "extension": ".txt",
        "import": True,
        "export_file": True,
        "export_clip": True
    },
    "rtf": {
        "name": _("Rich Text Format"),
        "extension": ".rtf",
        "import": True,
        "export_file": True,
        "export_clip": False
    }
}
