import pathlib          # Python Pathlib - https://docs.python.org/3/library/pathlib.html

import wx               # wxPython - https://wxpython.org/


class RecentList:
    def __init__(self):
        # get app obj
        self.app = wx.GetApp()
        self._ = self.app.constants.translation.gettext

        # pr`ocess the open files list into an array
        if self.app.config.Read("files/current") != "":
            self.open_list = (
                self.app.config.Read("files/current")
            ).split("|")
        else:
            self.open_list = [""]

        # process the recent files into an array
        if self.app.config.Read("files/recent") != "":
            self.file_list = (
                self.app.config.Read("files/recent")
            ).split("|")
        else:
            self.file_list = []

    def update(self, closing_file=None):
        current_list = []
        updated_list = []
        windows = []

        for top_win in wx.GetTopLevelWindows():
            if type(top_win).__name__ == "MainWin":
                windows.append(top_win)

        # get the currently open files
        for window in windows:
            if window.file.path.is_file():
                current_list.append(str(window.file.path.absolute()))

        # if we're multiwindow and there's a closing file
        if len(windows) > 1 and closing_file in current_list:
            current_list.remove(closing_file)
            self.file_list.insert(0, closing_file)

        # loop through the current list and see if any were closed
        # if so, add that to the recents list (will be checked/filtered soon)
        for this_file in self.open_list:
            if this_file not in current_list:
                self.file_list.insert(0, this_file)

        # loop through the recents list and filter/clean
        for idx, this_file in enumerate(self.file_list):
            this_file_obj = pathlib.Path(this_file)

            if (
                this_file in updated_list or  # already in the list
                str(this_file_obj.resolve()) in current_list or  # already open
                not pathlib.Path(this_file).is_file() or  # not a file
                idx > 10  # more than 10 items
            ):
                # invalid; skip!
                continue
            else:
                # file is good; append to list
                updated_list.append(this_file)

        # set the cleaned lists back to the object
        self.file_list = updated_list
        self.open_list = current_list

        # write back to settings
        self.app.config.Write("files/recent", "|".join(self.file_list))
        self.app.config.Write("files/current", "|".join(self.open_list))

        # update the menus
        for window in windows:
            self.update_menus(window)

        # save the settings update
        self.app.config.Flush()

    def update_menus(self, window):
        # get existing menu
        menu_items = window.file_recent.GetMenuItems()

        # wipe it out!
        for item in menu_items:
            window.file_recent.DestroyItem(item.GetId())

        # set up a new menu array
        new_menu = []

        if len(self.file_list) <= 0:
            this_menu = wx.MenuItem(
                window.file_recent,
                wx.ID_IGNORE,
                self._(u"No documents"),
                wx.EmptyString,
                wx.ITEM_NORMAL
            )
            new_menu.append(this_menu)
        else:
            for idx, file in enumerate(self.file_list):
                file_obj = pathlib.Path(file)
                this_menu_item = wx.MenuItem(
                    window.file_recent,
                    idx + 10000,
                    file_obj.name,
                    wx.EmptyString,
                    wx.ITEM_NORMAL
                )
                window.Bind(
                    wx.EVT_MENU,
                    window.event_menu_file_recent_open,
                    id=this_menu_item.GetId()
                )
                new_menu.append(this_menu_item)

            new_menu.append(
                wx.MenuItem(
                    window.file_recent,
                    wx.ID_ANY,
                    "",
                    wx.EmptyString,
                    wx.ITEM_SEPARATOR
                )
            )

            reset_recent = wx.MenuItem(
                window.file_recent,
                wx.ID_ANY,
                self._("Clear List")
            )
            window.Bind(
                wx.EVT_MENU,
                window.event_menu_file_recent_reset,
                id=reset_recent.GetId()
            )
            new_menu.append(reset_recent)

        for this_item in new_menu:
            window.file_recent.Append(this_item)
            if this_item.GetId() == wx.ID_IGNORE:
                this_item.Enable(False)

    def reset(self, window):
        self.file_list = []
        self.update(window)
