import markdown             # Python-Markdown - https://github.com/Python-Markdown/markdown
import wx                   # wxPython - https://wxpython.org/

from commit.ui.commit_ui_design import AboutWin_Base    # local - about window design from wxFormBuilder
from commit.ui.htmldisplaywin import HtmlDisplayWin     # local - about window
from commit.includes.customobjects import WindowThemeable   # local - custom objects

# wxPython HyperLinkCtrl - https://docs.wxpython.org/wx.lib.agw.hyperlink.HyperLinkCtrl.html
from wx.lib.agw.hyperlink import (
    HyperLinkCtrl
)


class AboutWin(AboutWin_Base, WindowThemeable):
    def __init__(self, parent):
        # call parent inits
        AboutWin_Base.__init__(self, parent)
        WindowThemeable.__init__(self, parent)

        # hide the updater settings if we're a non-update build
        if self.app.updater.disabled:
            self.version_check.Hide()

        # init translations
        _ = self._

        # window title
        self.SetTitle(_("About") + " " + self.app.constants.app_display_name)

        # title
        self.title_text.SetLabel(self.app.constants.app_display_name + ": " + self.app.constants.app_tagline)

        # byline
        self.byline_text.SetLabel(_("by") + " " + self.app.constants.app_credit)

        # version
        self.version_text.SetLabel(_("Version") + " " + str(self.app.constants.app_version))

        # product code
        self.product_code.SetLabel(self.app.constants.vendor_product_code)

        # website link
        self.website_link.SetLabel(_("Website"))

        # set up the links that we don't want to act like normal links
        self.credit_link.AutoBrowse(False)
        self.credit_link.Bind(
            wx.lib.agw.hyperlink.EVT_HYPERLINK_LEFT,
            self.do_launch_md_modal
        )

        self.license_link.AutoBrowse(False)
        self.license_link.Bind(
            wx.lib.agw.hyperlink.EVT_HYPERLINK_LEFT,
            self.do_launch_md_modal
        )

        # set the website link
        self.website_link.SetURL(
            wx.GetApp().constants.app_website
        )

        # set the manual link
        self.manual_link.SetURL(
            wx.GetApp().constants.app_help_url
        )

        # set the donate link
        self.donate_link.SetURL(
            wx.GetApp().constants.app_donate_url
        )

        self.close_button.SetFocus()
        self.Fit()
        self.Center()

    def do_launch_md_modal(self, event):
        title = event.GetEventObject().GetLabel()
        target_file = event.GetEventObject().GetURL()
        preproc = False

        # some custom titles
        if target_file == "CREDITS.md":
            title = self._("Credits and Acknowledgements")
            preproc = True
        elif target_file == "LICENSE.md":
            title = self._("Software License")

        # get the credits file
        with open(target_file) as md_file:
            md_content = md_file.read()

        html_modal = HtmlDisplayWin(
            self,
            title=title,
            html_content=markdown.markdown(md_content),
            preproc=preproc
        )

        html_modal.ShowModal()

    def do_update_check(self, event):
        # do the update check
        self.app.updater.do_update_check(self)
