import wx           # wxPython - https://wxpython.org/

from commit.ui.commit_ui_design import PrefsWin_Base   # local - about window design from wxFormBuilder
from commit.includes.customobjects import WindowThemeable   # local - custom objects


class PrefsWin(PrefsWin_Base, WindowThemeable):
    def __init__(self, parent):
        # call parent inits
        PrefsWin_Base.__init__(self, parent)
        WindowThemeable.__init__(self, parent)

        # get app obj
        app = self.app

        # hide the updater settings if we're a non-update build
        if self.app.updater.disabled:
            self.update_panel.Hide()

        # build the theme list and place into the dropdowns
        theme_list = []
        theme_list_fs = ["(None)"]
        for this_theme in self.app.constants.themes:
            theme_list.append(
                this_theme[1]
            )
            theme_list_fs.append(
                this_theme[1]
            )
        self.pref_select_theme.Set(theme_list)
        self.pref_select_fs_theme.Set(theme_list_fs)

        # build the ratio list and place into the dropdown
        ratio_list = []
        for this_ratio in self.app.constants.fs_ratio_map:
            ratio_list.append(
                this_ratio[1]
            )
        self.pref_select_fs_ratio.Set(ratio_list)

        # set values to match current settings
        self.pref_select_splash.SetValue(
            app.config.ReadBool("startup/show_splash")
        )
        self.pref_select_open_last.SetValue(
            app.config.ReadBool("startup/open_last_edited")
        )
        self.pref_select_saveoncommit.SetValue(
            app.config.ReadBool("options/auto-save-commit")
        )
        self.pref_select_soundoncommit.SetValue(
            app.config.ReadInt("options/commit-sounds")
        )
        self.pref_select_disablescroll.SetValue(
            app.config.ReadInt("options/disable-scrolling")
        )
        self.pref_select_theme.SetSelection(
            app.config.ReadInt("view/theme")
        )
        self.pref_select_fs_theme.SetSelection(
            app.config.ReadInt("view/fs_theme") + 1
        )
        self.pref_select_fs_ratio.SetSelection(
            app.config.ReadInt("view/fs_ratio")
        )
        self.pref_select_font.SetSelectedFont(
            wx.Font(app.config.Read("view/font"))
        )
        self.pref_select_gen_colors.SetValue(
            app.config.ReadBool("view/gen_colors")
        )
        self.pref_select_gen_icons.SetValue(
            app.config.ReadBool("view/gen_icons")
        )
        self.pref_select_statusbar.SetValue(
            app.config.ReadBool("statusbar/show")
        )
        self.pref_select_wordcount.SetValue(
            app.config.ReadBool("statusbar/show_word_count")
        )
        self.pref_select_session_wordcount.SetValue(
            app.config.ReadBool("statusbar/show_session_word_count")
        )
        self.pref_select_update_interval.SetSelection(
            app.config.ReadInt("updates/interval")
        )

        self.toggle_show_statusbar()

        self.Fit()
        self.Center()

    def do_prefs_font_change(self, event=None):
        event.Skip()
        self.Fit()

    def do_update_check(self, event):
        # do the update check
        self.app.updater.do_update_check(self)

    def do_prefs_reset(self, event):
        _ = self._
        confirm_dialog = wx.MessageDialog(
            self,
            _("This will completely reset and then close the application."),
            _("Confirm Reset"),
            wx.OK | wx.CANCEL | wx.CANCEL_DEFAULT | wx.ICON_WARNING
        )
        confirm_result = confirm_dialog.ShowModal()

        if confirm_result == wx.ID_OK:
            self.EndModal(wx.ID_NONE)

            # set the reset flag and force close the app
            self.app.is_config_reset = True

            # delete prefs file
            self.app.config.Destroy()
            self.app.config.file_path.unlink()

            self.app.force_close_app()

    def do_prefs_save(self, event):
        app = self.app

        # save the updated values
        app.config.WriteBool(
            "startup/show_splash",
            self.pref_select_splash.GetValue()
        )
        app.config.WriteBool(
            "startup/open_last_edited",
            self.pref_select_open_last.GetValue()
        )
        app.config.WriteBool(
            "options/auto-save-commit",
            self.pref_select_saveoncommit.GetValue()
        )
        app.config.WriteBool(
            "options/commit-sounds",
            self.pref_select_soundoncommit.GetValue()
        )
        app.config.WriteBool(
            "options/disable-scrolling",
            self.pref_select_disablescroll.GetValue()
        )
        app.config.WriteInt(
            "view/theme",
            self.pref_select_theme.GetSelection()
        )
        app.config.WriteInt(
            "view/fs_theme",
            self.pref_select_fs_theme.GetSelection() - 1
        )
        app.config.WriteInt(
            "view/fs_ratio",
            self.pref_select_fs_ratio.GetSelection()
        )
        app.config.Write(
            "view/font",
            self.pref_select_font.GetSelectedFont().GetNativeFontInfoDesc()
        )
        app.config.WriteBool(
            "view/gen_colors",
            self.pref_select_gen_colors.GetValue()
        )
        app.config.WriteBool(
            "view/gen_icons",
            self.pref_select_gen_icons.GetValue()
        )
        app.config.WriteBool(
            "statusbar/show",
            self.pref_select_statusbar.GetValue()
        )
        app.config.WriteBool(
            "statusbar/show_word_count",
            self.pref_select_wordcount.GetValue()
        )
        app.config.WriteBool(
            "statusbar/show_session_word_count",
            self.pref_select_session_wordcount.GetValue()
        )
        app.config.WriteInt(
            "updates/interval",
            self.pref_select_update_interval.GetSelection()
        )

        # save the modifications
        app.config.Flush()

        # close the prefs window
        self.EndModal(wx.ID_SAVE)

    def toggle_show_statusbar(self, event=None):
        if event is not None:
            event.Skip()

        status_select = self.pref_select_statusbar.GetValue()

        self.pref_select_wordcount.Enable(status_select)
        self.pref_select_session_wordcount.Enable(status_select)
